@@ -10,18 +10,17 @@ import logging
 import os
 import sys
 from datetime import datetime
+from importlib.util import find_spec
+
 from rich.logging import RichHandler
 
 from fancylog.tools.git import (
-    get_git_info,
     GitEnvironmentError,
     GitPythonError,
+    get_git_info,
 )
 
 
-from importlib.util import find_spec
-
-
 def start_logging(
     output_dir=None,
     package=None,
@@ -30,12 +29,13 @@ def start_logging(
     file_log_level="DEBUG",
     filename=None,
     log_header="LOG",
-    multiprocessing_aware=True,
+    multiprocessing_aware=False,
     write_header=True,
     write_git=True,
     write_cli_args=True,
     write_variables=True,
     log_to_file=True,
+    log_to_console=True,
     timestamp=True,
 ):
     """
@@ -61,9 +61,11 @@ def start_logging(
     :param log_to_file: If True, write a log file, otherwise just print to
     terminal.
     :param timestamp: If True, add a timestamp to the filename
-    :return: Path to the logging file
+    :param log_to_console: Print logs to the console or not: Default: True
+    :return: Path to the logging file#
     """
-    # TODO: accept PosixPath
+
+    output_dir = str(output_dir)
     if verbose:
         print_log_level = "DEBUG"
     else:
@@ -100,6 +102,7 @@ def start_logging(
         print_level=print_log_level,
         file_level=file_log_level,
         multiprocessing_aware=multiprocessing_aware,
+        log_to_console=log_to_console,
     )
     return logging_file
 
@@ -173,7 +176,17 @@ class LoggingHeader:
 
     def write_variables(self, variable_objects):
         self.write_separated_section_header("VARIABLES", bottom_separator="\n")
+        if hasattr(variable_objects[0], "__dict__"):
+            self.write_variables_from_object_list(variable_objects)
+        else:
+            self.write_variables_from_slot_type_list(variable_objects)
+        self.write_separated_section_header("LOGGING")
 
+    def write_variables_from_slot_type_list(self, variable_objects):
+        for attr, value in variable_objects._asdict().items():
+            self.file.write(f"{attr}: {value}\n")
+
+    def write_variables_from_object_list(self, variable_objects):
         for variable_object in variable_objects:
             self.file.write(f"\n{variable_object.__class__.__name__}:\n")
             for attr, value in variable_object.__dict__.items():
@@ -181,8 +194,6 @@ class LoggingHeader:
                 if value not in variable_objects:
                     self.file.write(f"{attr}: {value}\n")
 
-        self.write_separated_section_header("LOGGING")
-
     def write_log_header(self, output_dir, log_header):
         if log_header is None:
             log_header = "LOG"
@@ -224,11 +235,11 @@ class LoggingHeader:
         )
 
 
-def setup_logging(
+def initalise_logger(
     filename,
     print_level="INFO",
     file_level="DEBUG",
-    multiprocessing_aware=True,
+    log_to_console=True,
 ):
     """
     Sets up (possibly multiprocessing aware) logging.
@@ -237,8 +248,7 @@ def setup_logging(
     Default: 'INFO'
     :param file_level: What level of logging to print to file.
     Default: 'DEBUG'
-    :param multiprocessing_aware: Default: True
-
+    :param log_to_console: Print logs to the console or not
     """
     logger = logging.getLogger()
     logger.setLevel(getattr(logging, file_level))
@@ -251,15 +261,46 @@ def setup_logging(
     formatter.datefmt = "%Y-%m-%d %H:%M:%S %p"
 
     if filename is not None:
-        fh = logging.FileHandler(filename)
+        fh = logging.FileHandler(filename, encoding="utf-8")
         fh.setLevel(getattr(logging, file_level))
         fh.setFormatter(formatter)
         logger.addHandler(fh)
 
-    ch = RichHandler()
-    ch.setLevel(getattr(logging, print_level))
-    ch.setFormatter(formatter)
-    logger.addHandler(ch)
+    if log_to_console:
+        ch = RichHandler()
+        ch.setLevel(getattr(logging, print_level))
+        ch.setFormatter(formatter)
+        logger.addHandler(ch)
+
+    return logger
+
+
+def setup_logging(
+    filename,
+    print_level="INFO",
+    file_level="DEBUG",
+    multiprocessing_aware=True,
+    log_to_console=True,
+):
+    """
+    Sets up (possibly multiprocessing aware) logging.
+    :param filename: Where to save the logs to
+    :param print_level: What level of logging to print to console.
+    Default: 'INFO'
+    :param file_level: What level of logging to print to file.
+    Default: 'DEBUG'
+    :param multiprocessing_aware: Default: True
+    :param log_to_console: Print logs to the console or no.
+    Default: True
+
+    """
+
+    initalise_logger(
+        filename,
+        print_level=print_level,
+        file_level=file_level,
+        log_to_console=log_to_console,
+    )
     if multiprocessing_aware:
         try:
             import multiprocessing_logging
@@ -287,4 +328,4 @@ def disable_logging():
     no argument doesn't work.
     :return:
     """
-    logging.disable(2 ** 63 - 1)
+    logging.disable(2**63 - 1)
